@@ -12,7 +12,7 @@ from rrshare.rqUtil.rqSql import rq_util_sql_postgres_setting
 # 文件的创建步骤，他还会创建一个setting的dir
 
 POSTGRESQL_URI = setting["POSTGRESQL"]
-#print(POSTGRESQL_URI)
+print(POSTGRESQL_URI)
 CONFIGFILE_PATH = '{}{}{}'.format(setting_path, os.sep, 'config.ini')
 #print(CONFIGFILE_PATH)
 
